@@ -36,7 +36,6 @@ import javax.net.ssl.SSLParameters;
 import javax.net.ssl.SSLServerSocketFactory;
 
 import org.apache.hc.core5.function.Callback;
-import org.apache.hc.core5.function.Supplier;
 import org.apache.hc.core5.http.ClassicHttpResponse;
 import org.apache.hc.core5.http.ConnectionReuseStrategy;
 import org.apache.hc.core5.http.ExceptionListener;
@@ -277,7 +276,7 @@ public class ServerBootstrap {
         Args.notBlank(existing, "Existing");
         Args.notBlank(name, "Name");
         Args.notNull(filterHandler, "Filter handler");
-        filters.add(new FilterEntry<>(FilterEntry.Postion.BEFORE, name, filterHandler, existing));
+        filters.add(new FilterEntry<>(FilterEntry.Position.BEFORE, name, filterHandler, existing));
         return this;
     }
 
@@ -288,7 +287,7 @@ public class ServerBootstrap {
         Args.notBlank(existing, "Existing");
         Args.notBlank(name, "Name");
         Args.notNull(filterHandler, "Filter handler");
-        filters.add(new FilterEntry<>(FilterEntry.Postion.AFTER, name, filterHandler, existing));
+        filters.add(new FilterEntry<>(FilterEntry.Position.AFTER, name, filterHandler, existing));
         return this;
     }
 
@@ -298,7 +297,7 @@ public class ServerBootstrap {
     public final ServerBootstrap replaceFilter(final String existing, final HttpFilterHandler filterHandler) {
         Args.notBlank(existing, "Existing");
         Args.notNull(filterHandler, "Filter handler");
-        filters.add(new FilterEntry<>(FilterEntry.Postion.REPLACE, existing, filterHandler, existing));
+        filters.add(new FilterEntry<>(FilterEntry.Position.REPLACE, existing, filterHandler, existing));
         return this;
     }
 
@@ -308,7 +307,7 @@ public class ServerBootstrap {
     public final ServerBootstrap addFilterFirst(final String name, final HttpFilterHandler filterHandler) {
         Args.notNull(name, "Name");
         Args.notNull(filterHandler, "Filter handler");
-        filters.add(new FilterEntry<>(FilterEntry.Postion.FIRST, name, filterHandler, null));
+        filters.add(new FilterEntry<>(FilterEntry.Position.FIRST, name, filterHandler, null));
         return this;
     }
 
@@ -318,22 +317,15 @@ public class ServerBootstrap {
     public final ServerBootstrap addFilterLast(final String name, final HttpFilterHandler filterHandler) {
         Args.notNull(name, "Name");
         Args.notNull(filterHandler, "Filter handler");
-        filters.add(new FilterEntry<>(FilterEntry.Postion.LAST, name, filterHandler, null));
+        filters.add(new FilterEntry<>(FilterEntry.Position.LAST, name, filterHandler, null));
         return this;
     }
 
     public HttpServer create() {
         final RequestHandlerRegistry<HttpRequestHandler> handlerRegistry = new RequestHandlerRegistry<>(
                 canonicalHostName != null ? canonicalHostName : InetAddressUtils.getCanonicalLocalHostName(),
-                new Supplier<LookupRegistry<HttpRequestHandler>>() {
-
-                    @Override
-                    public LookupRegistry<HttpRequestHandler> get() {
-                        return lookupRegistry != null ? lookupRegistry :
-                                UriPatternType.<HttpRequestHandler>newMatcher(UriPatternType.URI_PATTERN);
-                    }
-
-                });
+                () -> lookupRegistry != null ? lookupRegistry :
+                        UriPatternType.newMatcher(UriPatternType.URI_PATTERN));
         for (final HandlerEntry<HttpRequestHandler> entry: handlerList) {
             handlerRegistry.register(entry.hostname, entry.uriPattern, entry.handler);
         }
@@ -351,7 +343,7 @@ public class ServerBootstrap {
                     StandardFilter.EXPECT_CONTINUE.name());
 
             for (final FilterEntry<HttpFilterHandler> entry: filters) {
-                switch (entry.postion) {
+                switch (entry.position) {
                     case AFTER:
                         filterChainDefinition.addAfter(entry.existing, entry.filterHandler, entry.name);
                         break;
@@ -407,7 +399,7 @@ public class ServerBootstrap {
         }
 
         return new HttpServer(
-                this.listenerPort > 0 ? this.listenerPort : 0,
+                Math.max(this.listenerPort, 0),
                 httpService,
                 this.localAddress,
                 this.socketConfig != null ? this.socketConfig : SocketConfig.DEFAULT,
