@@ -43,7 +43,6 @@ import java.util.concurrent.atomic.AtomicInteger;
 
 import javax.net.ssl.SSLSession;
 
-import org.apache.hc.core5.concurrent.Cancellable;
 import org.apache.hc.core5.concurrent.CancellableDependency;
 import org.apache.hc.core5.http.ConnectionClosedException;
 import org.apache.hc.core5.http.EndpointDetails;
@@ -435,11 +434,11 @@ abstract class AbstractH2StreamMultiplexer implements Identifiable, HttpConnecti
         if (connState == ConnectionHandshake.SHUTDOWN) {
             ioSession.clearEvent(SelectionKey.OP_READ);
         } else {
-            if (src != null) {
-                inputBuffer.put(src);
-            }
-            RawFrame frame;
-            while ((frame = inputBuffer.read(ioSession)) != null) {
+            for (;;) {
+                final RawFrame frame = inputBuffer.read(src, ioSession);
+                if (frame == null) {
+                    break;
+                }
                 if (streamListener != null) {
                     streamListener.onFrameInput(this, frame.getStreamId(), frame);
                 }
@@ -641,14 +640,7 @@ abstract class AbstractH2StreamMultiplexer implements Identifiable, HttpConnecti
                 }
                 final CancellableDependency cancellableDependency = executableCommand.getCancellableDependency();
                 if (cancellableDependency != null) {
-                    cancellableDependency.setDependency(new Cancellable() {
-
-                        @Override
-                        public boolean cancel() {
-                            return stream.abort();
-                        }
-
-                    });
+                    cancellableDependency.setDependency(stream::abort);
                 }
                 if (!outputQueue.isEmpty()) {
                     return;
@@ -1226,6 +1218,11 @@ abstract class AbstractH2StreamMultiplexer implements Identifiable, HttpConnecti
         final int delta = remoteConfig.getInitialWindowSize() - initOutputWinSize;
         initOutputWinSize = remoteConfig.getInitialWindowSize();
 
+        final int maxFrameSize = remoteConfig.getMaxFrameSize();
+        if (maxFrameSize > localConfig.getMaxFrameSize()) {
+            outputBuffer.expand(maxFrameSize);
+        }
+
         if (delta != 0) {
             if (!streamMap.isEmpty()) {
                 for (final Iterator<Map.Entry<Integer, H2Stream>> it = streamMap.entrySet().iterator(); it.hasNext(); ) {
