@@ -43,13 +43,16 @@ import javax.net.ssl.SSLEngine;
 import javax.net.ssl.SSLEngineResult;
 import javax.net.ssl.SSLEngineResult.HandshakeStatus;
 import javax.net.ssl.SSLException;
+import javax.net.ssl.SSLHandshakeException;
 import javax.net.ssl.SSLSession;
 
 import org.apache.hc.core5.annotation.Contract;
 import org.apache.hc.core5.annotation.Internal;
 import org.apache.hc.core5.annotation.ThreadingBehavior;
+import org.apache.hc.core5.concurrent.FutureCallback;
 import org.apache.hc.core5.function.Callback;
 import org.apache.hc.core5.io.CloseMode;
+import org.apache.hc.core5.io.SocketTimeoutExceptionFactory;
 import org.apache.hc.core5.net.NamedEndpoint;
 import org.apache.hc.core5.reactor.Command;
 import org.apache.hc.core5.reactor.EventMask;
@@ -57,7 +60,6 @@ import org.apache.hc.core5.reactor.IOEventHandler;
 import org.apache.hc.core5.reactor.IOSession;
 import org.apache.hc.core5.util.Args;
 import org.apache.hc.core5.util.Asserts;
-import org.apache.hc.core5.util.ReflectionUtils;
 import org.apache.hc.core5.util.Timeout;
 
 /**
@@ -85,7 +87,8 @@ public class SSLIOSession implements IOSession {
     private final SSLSessionVerifier verifier;
     private final Callback<SSLIOSession> sessionStartCallback;
     private final Callback<SSLIOSession> sessionEndCallback;
-    private final Timeout connectTimeout;
+    private final AtomicReference<FutureCallback<SSLSession>> handshakeCallbackRef;
+    private final Timeout handshakeTimeout;
     private final SSLMode sslMode;
     private final AtomicInteger outboundClosedCount;
     private final AtomicReference<TLSHandShakeState> handshakeStateRef;
@@ -123,6 +126,37 @@ public class SSLIOSession implements IOSession {
             final Callback<SSLIOSession> sessionStartCallback,
             final Callback<SSLIOSession> sessionEndCallback,
             final Timeout connectTimeout) {
+        this(targetEndpoint, session, sslMode, sslContext, sslBufferMode, initializer, verifier, connectTimeout,
+                sessionStartCallback, sessionEndCallback, null);
+    }
+
+    /**
+     * Creates new instance of {@code SSLIOSession} class.
+     *
+     * @param session I/O session to be decorated with the TLS/SSL capabilities.
+     * @param sslMode SSL mode (client or server)
+     * @param targetEndpoint target endpoint (applicable in client mode only). May be {@code null}.
+     * @param sslContext SSL context to use for this I/O session.
+     * @param sslBufferMode buffer management mode
+     * @param initializer optional SSL session initializer. May be {@code null}.
+     * @param verifier optional SSL session verifier. May be {@code null}.
+     * @param handshakeTimeout timeout to apply for the TLS/SSL handshake. May be {@code null}.
+     * @param resultCallback result callback. May be {@code null}.
+     *
+     * @since 5.2
+     */
+    public SSLIOSession(
+            final NamedEndpoint targetEndpoint,
+            final IOSession session,
+            final SSLMode sslMode,
+            final SSLContext sslContext,
+            final SSLBufferMode sslBufferMode,
+            final SSLSessionInitializer initializer,
+            final SSLSessionVerifier verifier,
+            final Timeout handshakeTimeout,
+            final Callback<SSLIOSession> sessionStartCallback,
+            final Callback<SSLIOSession> sessionEndCallback,
+            final FutureCallback<SSLSession> resultCallback) {
         super();
         Args.notNull(session, "IO session");
         Args.notNull(sslContext, "SSL context");
@@ -133,6 +167,7 @@ public class SSLIOSession implements IOSession {
         this.verifier = verifier;
         this.sessionStartCallback = sessionStartCallback;
         this.sessionEndCallback = sessionEndCallback;
+        this.handshakeCallbackRef = new AtomicReference<>(resultCallback);
 
         this.appEventMask = session.getEventMask();
         if (this.sslMode == SSLMode.CLIENT && targetEndpoint != null) {
@@ -152,21 +187,16 @@ public class SSLIOSession implements IOSession {
         this.inPlain = SSLManagedBuffer.create(sslBufferMode, appBufferSize);
         this.outboundClosedCount = new AtomicInteger(0);
         this.handshakeStateRef = new AtomicReference<>(TLSHandShakeState.READY);
-        this.connectTimeout = connectTimeout;
+        this.handshakeTimeout = handshakeTimeout;
         this.internalEventHandler = new IOEventHandler() {
 
             @Override
             public void connected(final IOSession protocolSession) throws IOException {
-                if (handshakeStateRef.compareAndSet(TLSHandShakeState.READY, TLSHandShakeState.INITIALIZED)) {
-                    initialize(protocolSession);
-                }
+                beginHandshake(protocolSession);
             }
 
             @Override
             public void inputReady(final IOSession protocolSession, final ByteBuffer src) throws IOException {
-                if (handshakeStateRef.compareAndSet(TLSHandShakeState.READY, TLSHandShakeState.INITIALIZED)) {
-                    initialize(protocolSession);
-                }
                 receiveEncryptedData();
                 doHandshake(protocolSession);
                 decryptData(protocolSession);
@@ -175,9 +205,6 @@ public class SSLIOSession implements IOSession {
 
             @Override
             public void outputReady(final IOSession protocolSession) throws IOException {
-                if (handshakeStateRef.compareAndSet(TLSHandShakeState.READY, TLSHandShakeState.INITIALIZED)) {
-                    initialize(protocolSession);
-                }
                 encryptData(protocolSession);
                 sendEncryptedData();
                 doHandshake(protocolSession);
@@ -190,11 +217,19 @@ public class SSLIOSession implements IOSession {
                     // The session failed to terminate cleanly
                     close(CloseMode.IMMEDIATE);
                 }
-                ensureHandler().timeout(protocolSession, timeout);
+                if (handshakeStateRef.get() != TLSHandShakeState.COMPLETE) {
+                    exception(protocolSession, SocketTimeoutExceptionFactory.create(handshakeTimeout));
+                } else {
+                    ensureHandler().timeout(protocolSession, timeout);
+                }
             }
 
             @Override
             public void exception(final IOSession protocolSession, final Exception cause) {
+                final FutureCallback<SSLSession> resultCallback = handshakeCallbackRef.getAndSet(null);
+                if (resultCallback != null) {
+                    resultCallback.failed(cause);
+                }
                 final IOEventHandler handler = session.getHandler();
                 if (handshakeStateRef.get() != TLSHandShakeState.COMPLETE) {
                     session.close(CloseMode.GRACEFUL);
@@ -228,11 +263,17 @@ public class SSLIOSession implements IOSession {
         return internalEventHandler;
     }
 
+    public void beginHandshake(final IOSession protocolSession) throws IOException {
+        if (handshakeStateRef.compareAndSet(TLSHandShakeState.READY, TLSHandShakeState.INITIALIZED)) {
+            initialize(protocolSession);
+        }
+    }
+
     private void initialize(final IOSession protocolSession) throws IOException {
         // Save the initial socketTimeout of the underlying IOSession, to be restored after the handshake is finished
         this.socketTimeout = this.session.getSocketTimeout();
-        if (connectTimeout != null) {
-            this.session.setSocketTimeout(connectTimeout);
+        if (handshakeTimeout != null) {
+            this.session.setSocketTimeout(handshakeTimeout);
         }
 
         this.session.getLock().lock();
@@ -257,6 +298,7 @@ public class SSLIOSession implements IOSession {
             this.inEncrypted.release();
             this.outEncrypted.release();
             doHandshake(protocolSession);
+            updateEventMask();
         } finally {
             this.session.getLock().unlock();
         }
@@ -384,7 +426,7 @@ public class SSLIOSession implements IOSession {
             }
             if (this.tlsDetails == null) {
                 final SSLSession sslSession = this.sslEngine.getSession();
-                final String applicationProtocol = ReflectionUtils.callGetter(this.sslEngine, "ApplicationProtocol", String.class);
+                final String applicationProtocol = this.sslEngine.getApplicationProtocol();
                 this.tlsDetails = new TlsDetails(sslSession, applicationProtocol);
             }
 
@@ -393,6 +435,10 @@ public class SSLIOSession implements IOSession {
             if (this.sessionStartCallback != null) {
                 this.sessionStartCallback.execute(this);
             }
+            final FutureCallback<SSLSession> resultCallback = handshakeCallbackRef.getAndSet(null);
+            if (resultCallback != null) {
+                resultCallback.completed(sslEngine.getSession());
+            }
         }
     }
 
@@ -403,6 +449,10 @@ public class SSLIOSession implements IOSession {
             if (this.status == Status.ACTIVE
                     && (this.endOfStream || this.sslEngine.isInboundDone())) {
                 this.status = Status.CLOSING;
+                final FutureCallback<SSLSession> resultCallback = handshakeCallbackRef.getAndSet(null);
+                if (resultCallback != null) {
+                    resultCallback.failed(new SSLHandshakeException("TLS handshake failed"));
+                }
             }
             if (this.status == Status.CLOSING && !this.outEncrypted.hasData()) {
                 this.sslEngine.closeOutbound();
