@@ -44,9 +44,9 @@ import org.apache.hc.core5.http.impl.DefaultContentLengthStrategy;
 import org.apache.hc.core5.http.io.entity.ByteArrayEntity;
 import org.apache.hc.core5.http.io.entity.StringEntity;
 import org.apache.hc.core5.http.message.BasicClassicHttpRequest;
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 import org.mockito.Mock;
 import org.mockito.Mockito;
 import org.mockito.MockitoAnnotations;
@@ -58,21 +58,21 @@ public class TestDefaultBHttpClientConnection {
 
     private DefaultBHttpClientConnection conn;
 
-    @Before
-    public void setUp() throws Exception {
-        MockitoAnnotations.initMocks(this);
+    @BeforeEach
+    public void prepareMocks() {
+        MockitoAnnotations.openMocks(this);
         conn = new DefaultBHttpClientConnection(Http1Config.DEFAULT,
-            null, null,
-            DefaultContentLengthStrategy.INSTANCE,
-            DefaultContentLengthStrategy.INSTANCE,
-            DefaultHttpRequestWriterFactory.INSTANCE,
-            DefaultHttpResponseParserFactory.INSTANCE);
+                null, null,
+                DefaultContentLengthStrategy.INSTANCE,
+                DefaultContentLengthStrategy.INSTANCE,
+                DefaultHttpRequestWriterFactory.INSTANCE,
+                DefaultHttpResponseParserFactory.INSTANCE);
     }
 
     @Test
     public void testBasics() throws Exception {
-        Assert.assertFalse(conn.isOpen());
-        Assert.assertEquals("[Not bound]", conn.toString());
+        Assertions.assertFalse(conn.isOpen());
+        Assertions.assertEquals("[Not bound]", conn.toString());
     }
 
     @Test
@@ -83,13 +83,13 @@ public class TestDefaultBHttpClientConnection {
 
         conn.bind(socket);
 
-        Assert.assertEquals(0, conn.getEndpointDetails().getResponseCount());
+        Assertions.assertEquals(0, conn.getEndpointDetails().getResponseCount());
 
         final ClassicHttpResponse response = conn.receiveResponseHeader();
-        Assert.assertNotNull(response);
-        Assert.assertEquals(200, response.getCode());
-        Assert.assertTrue(response.containsHeader("User-Agent"));
-        Assert.assertEquals(1, conn.getEndpointDetails().getResponseCount());
+        Assertions.assertNotNull(response);
+        Assertions.assertEquals(200, response.getCode());
+        Assertions.assertTrue(response.containsHeader("User-Agent"));
+        Assertions.assertEquals(1, conn.getEndpointDetails().getResponseCount());
     }
 
     @Test
@@ -100,28 +100,28 @@ public class TestDefaultBHttpClientConnection {
 
         conn.bind(socket);
 
-        Assert.assertEquals(0, conn.getEndpointDetails().getResponseCount());
+        Assertions.assertEquals(0, conn.getEndpointDetails().getResponseCount());
 
         final ClassicHttpResponse response = conn.receiveResponseHeader();
 
-        Assert.assertNotNull(response);
-        Assert.assertEquals(200, response.getCode());
-        Assert.assertTrue(response.containsHeader("Server"));
-        Assert.assertEquals(1, conn.getEndpointDetails().getResponseCount());
+        Assertions.assertNotNull(response);
+        Assertions.assertEquals(200, response.getCode());
+        Assertions.assertTrue(response.containsHeader("Server"));
+        Assertions.assertEquals(1, conn.getEndpointDetails().getResponseCount());
 
         conn.receiveResponseEntity(response);
 
         final HttpEntity entity = response.getEntity();
-        Assert.assertNotNull(entity);
-        Assert.assertEquals(-1, entity.getContentLength());
-        Assert.assertEquals(1, conn.getEndpointDetails().getResponseCount());
+        Assertions.assertNotNull(entity);
+        Assertions.assertEquals(-1, entity.getContentLength());
+        Assertions.assertEquals(1, conn.getEndpointDetails().getResponseCount());
 
         final InputStream content = entity.getContent();
-        Assert.assertNotNull(content);
-        Assert.assertEquals(3, content.available());
-        Assert.assertEquals('1', content.read());
-        Assert.assertEquals('2', content.read());
-        Assert.assertEquals('3', content.read());
+        Assertions.assertNotNull(content);
+        Assertions.assertEquals(3, content.available());
+        Assertions.assertEquals('1', content.read());
+        Assertions.assertEquals('2', content.read());
+        Assertions.assertEquals('3', content.read());
     }
 
     @Test
@@ -132,24 +132,24 @@ public class TestDefaultBHttpClientConnection {
 
         conn.bind(socket);
 
-        Assert.assertEquals(0, conn.getEndpointDetails().getResponseCount());
+        Assertions.assertEquals(0, conn.getEndpointDetails().getResponseCount());
 
         final ClassicHttpResponse response = conn.receiveResponseHeader();
 
-        Assert.assertNotNull(response);
-        Assert.assertEquals(200, response.getCode());
-        Assert.assertTrue(response.containsHeader("Server"));
-        Assert.assertEquals(1, conn.getEndpointDetails().getResponseCount());
+        Assertions.assertNotNull(response);
+        Assertions.assertEquals(200, response.getCode());
+        Assertions.assertTrue(response.containsHeader("Server"));
+        Assertions.assertEquals(1, conn.getEndpointDetails().getResponseCount());
 
         conn.receiveResponseEntity(response);
 
         final HttpEntity entity = response.getEntity();
-        Assert.assertNotNull(entity);
-        Assert.assertEquals(3, entity.getContentLength());
-        Assert.assertEquals(1, conn.getEndpointDetails().getResponseCount());
+        Assertions.assertNotNull(entity);
+        Assertions.assertEquals(3, entity.getContentLength());
+        Assertions.assertEquals(1, conn.getEndpointDetails().getResponseCount());
         final InputStream content = entity.getContent();
-        Assert.assertNotNull(content);
-        Assert.assertTrue(content instanceof ContentLengthInputStream);
+        Assertions.assertNotNull(content);
+        Assertions.assertTrue(content instanceof ContentLengthInputStream);
     }
 
     @Test
@@ -161,28 +161,28 @@ public class TestDefaultBHttpClientConnection {
 
         conn.bind(socket);
 
-        Assert.assertEquals(0, conn.getEndpointDetails().getResponseCount());
+        Assertions.assertEquals(0, conn.getEndpointDetails().getResponseCount());
 
         final ClassicHttpResponse response = conn.receiveResponseHeader();
 
-        Assert.assertNotNull(response);
-        Assert.assertEquals(200, response.getCode());
-        Assert.assertTrue(response.containsHeader("Server"));
-        Assert.assertEquals(1, conn.getEndpointDetails().getResponseCount());
+        Assertions.assertNotNull(response);
+        Assertions.assertEquals(200, response.getCode());
+        Assertions.assertTrue(response.containsHeader("Server"));
+        Assertions.assertEquals(1, conn.getEndpointDetails().getResponseCount());
 
         conn.receiveResponseEntity(response);
 
         final HttpEntity entity = response.getEntity();
-        Assert.assertNotNull(entity);
-        Assert.assertEquals(-1, entity.getContentLength());
-        Assert.assertEquals(true, entity.isChunked());
-        Assert.assertEquals(1, conn.getEndpointDetails().getResponseCount());
+        Assertions.assertNotNull(entity);
+        Assertions.assertEquals(-1, entity.getContentLength());
+        Assertions.assertTrue(entity.isChunked());
+        Assertions.assertEquals(1, conn.getEndpointDetails().getResponseCount());
         final InputStream content = entity.getContent();
-        Assert.assertNotNull(content);
-        Assert.assertTrue(content instanceof ChunkedInputStream);
+        Assertions.assertNotNull(content);
+        Assertions.assertTrue(content instanceof ChunkedInputStream);
     }
 
-    @Test(expected = NotImplementedException.class)
+    @Test
     public void testReadResponseEntityIdentity() throws Exception {
         final String s = "HTTP/1.1 200 OK\r\nServer: test\r\nTransfer-Encoding: identity\r\n\r\n123";
         final ByteArrayInputStream inStream = new ByteArrayInputStream(s.getBytes(StandardCharsets.US_ASCII));
@@ -190,16 +190,17 @@ public class TestDefaultBHttpClientConnection {
 
         conn.bind(socket);
 
-        Assert.assertEquals(0, conn.getEndpointDetails().getResponseCount());
+        Assertions.assertEquals(0, conn.getEndpointDetails().getResponseCount());
 
         final ClassicHttpResponse response = conn.receiveResponseHeader();
 
-        Assert.assertNotNull(response);
-        Assert.assertEquals(200, response.getCode());
-        Assert.assertTrue(response.containsHeader("Server"));
-        Assert.assertEquals(1, conn.getEndpointDetails().getResponseCount());
+        Assertions.assertNotNull(response);
+        Assertions.assertEquals(200, response.getCode());
+        Assertions.assertTrue(response.containsHeader("Server"));
+        Assertions.assertEquals(1, conn.getEndpointDetails().getResponseCount());
 
-        conn.receiveResponseEntity(response);
+        Assertions.assertThrows(NotImplementedException.class, () ->
+                conn.receiveResponseEntity(response));
     }
 
     @Test
@@ -210,22 +211,22 @@ public class TestDefaultBHttpClientConnection {
 
         conn.bind(socket);
 
-        Assert.assertEquals(0, conn.getEndpointDetails().getResponseCount());
+        Assertions.assertEquals(0, conn.getEndpointDetails().getResponseCount());
 
         final ClassicHttpResponse response = conn.receiveResponseHeader();
 
-        Assert.assertNotNull(response);
-        Assert.assertEquals(200, response.getCode());
-        Assert.assertTrue(response.containsHeader("Server"));
-        Assert.assertEquals(1, conn.getEndpointDetails().getResponseCount());
+        Assertions.assertNotNull(response);
+        Assertions.assertEquals(200, response.getCode());
+        Assertions.assertTrue(response.containsHeader("Server"));
+        Assertions.assertEquals(1, conn.getEndpointDetails().getResponseCount());
 
         conn.receiveResponseEntity(response);
 
         final HttpEntity entity = response.getEntity();
-        Assert.assertNotNull(entity);
+        Assertions.assertNotNull(entity);
         final InputStream content = entity.getContent();
-        Assert.assertNotNull(content);
-        Assert.assertTrue(content instanceof IdentityInputStream);
+        Assertions.assertNotNull(content);
+        Assertions.assertTrue(content instanceof IdentityInputStream);
     }
 
     @Test
@@ -235,7 +236,7 @@ public class TestDefaultBHttpClientConnection {
 
         conn.bind(socket);
 
-        Assert.assertEquals(0, conn.getEndpointDetails().getRequestCount());
+        Assertions.assertEquals(0, conn.getEndpointDetails().getRequestCount());
 
         final ClassicHttpRequest request = new BasicClassicHttpRequest(Method.GET, "/stuff");
         request.addHeader("User-Agent", "test");
@@ -243,9 +244,9 @@ public class TestDefaultBHttpClientConnection {
         conn.sendRequestHeader(request);
         conn.flush();
 
-        Assert.assertEquals(1, conn.getEndpointDetails().getRequestCount());
+        Assertions.assertEquals(1, conn.getEndpointDetails().getRequestCount());
         final String s = new String(outStream.toByteArray(), StandardCharsets.US_ASCII);
-        Assert.assertEquals("GET /stuff HTTP/1.1\r\nUser-Agent: test\r\n\r\n", s);
+        Assertions.assertEquals("GET /stuff HTTP/1.1\r\nUser-Agent: test\r\n\r\n", s);
     }
 
     @Test
@@ -255,7 +256,7 @@ public class TestDefaultBHttpClientConnection {
 
         conn.bind(socket);
 
-        Assert.assertEquals(0, conn.getEndpointDetails().getRequestCount());
+        Assertions.assertEquals(0, conn.getEndpointDetails().getRequestCount());
 
         final ClassicHttpRequest request = new BasicClassicHttpRequest(Method.POST, "/stuff");
         request.addHeader("User-Agent", "test");
@@ -266,9 +267,9 @@ public class TestDefaultBHttpClientConnection {
         conn.sendRequestEntity(request);
         conn.flush();
 
-        Assert.assertEquals(1, conn.getEndpointDetails().getRequestCount());
+        Assertions.assertEquals(1, conn.getEndpointDetails().getRequestCount());
         final String s = new String(outStream.toByteArray(), StandardCharsets.US_ASCII);
-        Assert.assertEquals("POST /stuff HTTP/1.1\r\nUser-Agent: test\r\nContent-Length: 3\r\n\r\n123", s);
+        Assertions.assertEquals("POST /stuff HTTP/1.1\r\nUser-Agent: test\r\nContent-Length: 3\r\n\r\n123", s);
     }
 
     @Test
@@ -278,7 +279,7 @@ public class TestDefaultBHttpClientConnection {
 
         conn.bind(socket);
 
-        Assert.assertEquals(0, conn.getEndpointDetails().getRequestCount());
+        Assertions.assertEquals(0, conn.getEndpointDetails().getRequestCount());
 
         final ClassicHttpRequest request = new BasicClassicHttpRequest(Method.POST, "/stuff");
         request.addHeader("User-Agent", "test");
@@ -289,27 +290,28 @@ public class TestDefaultBHttpClientConnection {
         conn.sendRequestEntity(request);
         conn.flush();
 
-        Assert.assertEquals(1, conn.getEndpointDetails().getRequestCount());
+        Assertions.assertEquals(1, conn.getEndpointDetails().getRequestCount());
         final String s = new String(outStream.toByteArray(), StandardCharsets.US_ASCII);
-        Assert.assertEquals("POST /stuff HTTP/1.1\r\nUser-Agent: test\r\nTransfer-Encoding: " +
+        Assertions.assertEquals("POST /stuff HTTP/1.1\r\nUser-Agent: test\r\nTransfer-Encoding: " +
                 "chunked\r\n\r\n3\r\n123\r\n0\r\n\r\n", s);
     }
 
-    @Test(expected = LengthRequiredException.class)
+    @Test
     public void testWriteRequestEntityNoContentLength() throws Exception {
         final ByteArrayOutputStream outStream = new ByteArrayOutputStream();
         Mockito.when(socket.getOutputStream()).thenReturn(outStream);
 
         conn.bind(socket);
 
-        Assert.assertEquals(0, conn.getEndpointDetails().getRequestCount());
+        Assertions.assertEquals(0, conn.getEndpointDetails().getRequestCount());
 
         final ClassicHttpRequest request = new BasicClassicHttpRequest(Method.POST, "/stuff");
         request.addHeader("User-Agent", "test");
         request.setEntity(new StringEntity("123", ContentType.TEXT_PLAIN));
 
         conn.sendRequestHeader(request);
-        conn.sendRequestEntity(request);
+        Assertions.assertThrows(LengthRequiredException.class, () ->
+                conn.sendRequestEntity(request));
     }
 
     @Test
@@ -319,7 +321,7 @@ public class TestDefaultBHttpClientConnection {
 
         conn.bind(socket);
 
-        Assert.assertEquals(0, conn.getEndpointDetails().getRequestCount());
+        Assertions.assertEquals(0, conn.getEndpointDetails().getRequestCount());
 
         final ClassicHttpRequest request = new BasicClassicHttpRequest(Method.POST, "/stuff");
         request.addHeader("User-Agent", "test");
@@ -328,9 +330,9 @@ public class TestDefaultBHttpClientConnection {
         conn.sendRequestEntity(request);
         conn.flush();
 
-        Assert.assertEquals(1, conn.getEndpointDetails().getRequestCount());
+        Assertions.assertEquals(1, conn.getEndpointDetails().getRequestCount());
         final String s = new String(outStream.toByteArray(), StandardCharsets.US_ASCII);
-        Assert.assertEquals("POST /stuff HTTP/1.1\r\nUser-Agent: test\r\n\r\n", s);
+        Assertions.assertEquals("POST /stuff HTTP/1.1\r\nUser-Agent: test\r\n\r\n", s);
     }
 
     @Test
@@ -340,7 +342,7 @@ public class TestDefaultBHttpClientConnection {
 
         conn.bind(socket);
 
-        Assert.assertEquals(0, conn.getEndpointDetails().getRequestCount());
+        Assertions.assertEquals(0, conn.getEndpointDetails().getRequestCount());
 
         final ClassicHttpRequest request = new BasicClassicHttpRequest(Method.POST, "/stuff");
         request.addHeader("User-Agent", "test");
@@ -353,11 +355,11 @@ public class TestDefaultBHttpClientConnection {
         conn.terminateRequest(request);
         conn.flush();
 
-        Assert.assertEquals(1, conn.getEndpointDetails().getRequestCount());
+        Assertions.assertEquals(1, conn.getEndpointDetails().getRequestCount());
         final String s = new String(outStream.toByteArray(), StandardCharsets.US_ASCII);
-        Assert.assertEquals("POST /stuff HTTP/1.1\r\nUser-Agent: test\r\nTransfer-Encoding: " +
+        Assertions.assertEquals("POST /stuff HTTP/1.1\r\nUser-Agent: test\r\nTransfer-Encoding: " +
                 "chunked\r\n\r\n0\r\n\r\n", s);
-        Assert.assertTrue(conn.isConsistent());
+        Assertions.assertTrue(conn.isConsistent());
     }
 
     @Test
@@ -367,7 +369,7 @@ public class TestDefaultBHttpClientConnection {
 
         conn.bind(socket);
 
-        Assert.assertEquals(0, conn.getEndpointDetails().getRequestCount());
+        Assertions.assertEquals(0, conn.getEndpointDetails().getRequestCount());
 
         final ClassicHttpRequest request = new BasicClassicHttpRequest(Method.POST, "/stuff");
         request.addHeader("User-Agent", "test");
@@ -379,11 +381,11 @@ public class TestDefaultBHttpClientConnection {
         conn.terminateRequest(request);
         conn.flush();
 
-        Assert.assertEquals(1, conn.getEndpointDetails().getRequestCount());
+        Assertions.assertEquals(1, conn.getEndpointDetails().getRequestCount());
         final String s = new String(outStream.toByteArray(), StandardCharsets.US_ASCII);
-        Assert.assertEquals("POST /stuff HTTP/1.1\r\nUser-Agent: test\r\nContent-Length: " +
+        Assertions.assertEquals("POST /stuff HTTP/1.1\r\nUser-Agent: test\r\nContent-Length: " +
                 "3\r\n\r\n123", s);
-        Assert.assertTrue(conn.isConsistent());
+        Assertions.assertTrue(conn.isConsistent());
     }
 
     @Test
@@ -393,7 +395,7 @@ public class TestDefaultBHttpClientConnection {
 
         conn.bind(socket);
 
-        Assert.assertEquals(0, conn.getEndpointDetails().getRequestCount());
+        Assertions.assertEquals(0, conn.getEndpointDetails().getRequestCount());
 
         final ClassicHttpRequest request = new BasicClassicHttpRequest(Method.POST, "/stuff");
         request.addHeader("User-Agent", "test");
@@ -405,11 +407,11 @@ public class TestDefaultBHttpClientConnection {
         conn.terminateRequest(request);
         conn.flush();
 
-        Assert.assertEquals(1, conn.getEndpointDetails().getRequestCount());
+        Assertions.assertEquals(1, conn.getEndpointDetails().getRequestCount());
         final String s = new String(outStream.toByteArray(), StandardCharsets.US_ASCII);
-        Assert.assertEquals("POST /stuff HTTP/1.1\r\nUser-Agent: test\r\nContent-Length: " +
+        Assertions.assertEquals("POST /stuff HTTP/1.1\r\nUser-Agent: test\r\nContent-Length: " +
                 "3000\r\n\r\n", s);
-        Assert.assertFalse(conn.isConsistent());
+        Assertions.assertFalse(conn.isConsistent());
     }
 
 }
